@@ -30,12 +30,9 @@ bwa index {newRef}
 #samtools faidx {humRef}
 #samtools faidx {virRef}
 samtools faidx {newRef}
-#java -Xmx4g -jar /home/wenjingu/tools/picard.jar \
-CreateSequenceDictionary R={humRef} O={humRef.replace('.fa','.dict')}
-#java -Xmx4g -jar /home/wenjingu/tools/picard.jar \
-CreateSequenceDictionary R={virRef} O={virRef.replace('.fa','.dict')}
-java -Xmx4g -jar /home/wenjingu/tools/picard.jar \
-CreateSequenceDictionary R={newRef} O={newRef.replace('.fa','.dict')}
+picard CreateSequenceDictionary R={humRef} O={humRef.replace('.fa','.dict')}
+picard CreateSequenceDictionary R={virRef} O={virRef.replace('.fa','.dict')}
+picard CreateSequenceDictionary R={newRef} O={newRef.replace('.fa','.dict')}
 ''')
     return None
 
@@ -89,7 +86,7 @@ def generate_alignment_bash(bash_file,ref,fq1,fq2,out_dir,gz = True):
 #java: full path of java
 def generate_indel_alignment_bash(bash_File,ref,out_dir):
     with open(bash_File,'w') as output:
-        output.write(f'''java -Xmx4g -jar /home/wenjingu/tools/picard.jar \
+        output.write(f'''picard \
 AddOrReplaceReadGroups \
 I={out_dir}/alignment.bam \
 O={out_dir}/alignment.RG.bam \
@@ -100,12 +97,12 @@ RGSM=sample \
 RGLB=sample
 samtools sort -o {out_dir}/alignment.RG.sort.bam {out_dir}/alignment.RG.bam
 samtools index {out_dir}/alignment.RG.sort.bam
-java -Xmx4g -jar /sw/med/centos7/gatk/3.7/GenomeAnalysisTK.jar \
+GenomeAnalysisTK \
 -T RealignerTargetCreator \
 -R {ref} \
 -I {out_dir}/alignment.RG.sort.bam \
 -o {out_dir}/alignment.RG.intervals
-java -Xmx4g -jar /sw/med/centos7/gatk/3.7/GenomeAnalysisTK.jar \
+GenomeAnalysisTK \
 -T IndelRealigner \
 -R {ref} \
 -I {out_dir}/alignment.RG.sort.bam \
@@ -120,7 +117,7 @@ def generate_mkdup_bash(bash_File,out_dir):
     with open(bash_File,'a') as output:
         output.write(f'''
 samtools sort -n -o {out_dir}/alignment.RG.indelre.sortbyQ.bam {out_dir}/alignment.RG.indelre.bam
-java -Xmx4g -jar /home/wenjingu/tools/picard.jar MarkDuplicates \
+picard MarkDuplicates \
 I={out_dir}/alignment.RG.indelre.sortbyQ.bam \
 O={out_dir}/alignment.RG.indelre.mkdup.bam \
 M={out_dir}/alignment.RG.indelre.mkdup.txt \
